<?php

namespace Drupal\exif_removal\Plugin\Validation\Constraint;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\exif_removal\ExifRemoval;
use Drupal\file\FileInterface;
use Drupal\file\Plugin\Validation\Constraint\BaseFileConstraintValidator;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Constraint;

/**
 * Applies EXIF Removal.
 */
class ExifRemovalConstraintValidator extends BaseFileConstraintValidator implements ContainerInjectionInterface {

  /**
   * Inject dependencies.
   */
  public function __construct(
    protected ExifRemoval $removal,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('exif_removal.removal')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function validate(mixed $value, Constraint $constraint) {
    if (!$value instanceof FileInterface) {
      return;
    }

    // Only attempt EXIF removal for supported mime types.
    $mime_types = ['image/jpeg'];
    if (!in_array($value->getMimeType(), $mime_types)) {
      return;
    }

    // Attempt to remove EXIF data.
    $this->removal->exifRemoval($value);

    // No need to add validation errors if EXIF removal fails
    // as this would prevent the file from being saved.
  }

}
